from solo.date import Date
from solo.netcdf import NetCDF
from r2d2 import store, date_sequence

date = '2020110112'
window_start = Date(date) - 3
# for the format see unix command 'man strftime
# we want YYYYMMDDHH
window_start = window_start.format('%Y%m%d%H')
obs_types = [
    'amsua_aqua',
    'amsua_metop-a',
    'amsua_metop-b',
    'amsua_metop-c',
    'amsua_n15',
    'amsua_n18',
    'amsua_n19'
]
parts = 6

#------------ Merge files -------------
for obs_type in obs_types:
    files_to_merge = []
    for part in range(parts):
        # {part:04d} means 4 digit integer prefixed with zeros
        filename = f'{obs_type}_hofx_gfs_{date}_{part:04d}.nc4'
        files_to_merge.append(filename)
    output_file = f'{obs_type}_hofx_gfs_{window_start}.nc4'
    print(output_file)
    nc = NetCDF(obs_type)
    nc.concat_files(files_to_merge, output_file)

#------------ Store files -------------
store(
    type='diag',
    model='gfs',
    experiment='Fabio001',
    date=window_start,
    user_date_format='%Y%m%d%H',
    obs_type=obs_types,
    source_file='$(obs_type)_hofx_gfs_$(date).nc4',
    time_window='PT6H',
    bg_step='PT6H',
    database='local'
)

