import shutil
import tarfile
from solo.date import Hour
from solo.logger import Logger
from solo.configuration import Configuration
from r2d2 import store, date_sequence

# we filter which files we want to extract from the tar file
def wanted(name, name_list):
    for n in name_list:
        if name.find(n) != -1:
            return True
    return False

logger = Logger('gdas')
config = Configuration('config.yaml')
dates = date_sequence(config.start, config.end, config.step)

for date in dates:
    d = Hour(date).format('%Y%m%d%H')
    # open the tar file given to us
    filename = f'{config.fc_root}/{d}_fcst.tar'
    logger.info(f'preparing {filename}')
    tar = tarfile.open(filename)
    # extract the names of the files in the tar and keep the ones we need
    members = [x for x in tar.getmembers() if wanted(x.name, config.forecast_files)]
    # untar needed files into the config.stage directory
    logger.info(f'extracting files from {filename}')
    tar.extractall(path=config.stage, members=members)

    """
    # now archive into the shared database
    store(
        type='fc',
        model='gfs',
        experiment='oper',
        step='PT06H',
        date=date,
        resolution='c768',
        file_type=['fv_core.res', 'fv_srf_wnd.res', 'fv_tracer.res', 'sfc_data'],
        tile=[1, 2, 3, 4, 5, 6],
        source_file=config.stage + '/$(valid_year)$(valid_month)$(valid_day)$(valid_hour)/$(valid_date).$(file_type).tile$(tile).nc',
        database='shared'
    )
    """

    # need to archive the metadata (coupler.res)
    store(
        type='fc',
        step='PT6H',
        model='gfs_metadata',
        experiment='oper',
        date=date,
        resolution='c768',
        source_file=config.stage + '/$(valid_year)$(valid_month)$(valid_day)$(valid_hour)/$(valid_date).coupler.res',
        database = 'shared'
    )
    
    # done the with source files
    directory = f'{config.stage}/{d}'
    logger.info(f'deleting directory {directory}')
    shutil.rmtree(directory)

