import os
import shutil
import tarfile
from solo.date import Hour, JediDate, DateIncrement
from solo.logger import Logger
from solo.configuration import Configuration
from r2d2 import store, date_sequence

logger = Logger('gdas')
config = Configuration('config.yaml')
dates = date_sequence(config.start, config.end, config.step)

file_obs_types = {}
for o in config.obs_type:
    file_obs_types[o] = o
file_obs_types['radiosondes'] = 'radiosonde'

for date in dates:
    d = Hour(date).format('%Y%m%d%H')
    dd = Hour(date)
    window_start = str(JediDate(date) - DateIncrement('PT3H'))
    # open the tar file given to us
    filename = f'{config.ob_root}/{d}_conv.tar'
    logger.info(f'preparing {filename}')
    if os.path.exists(filename):
        tar = tarfile.open(filename)
        logger.info(f'extracting files from {filename}')
        tar.extractall(path=config.stage)

        for obs_type in config.obs_type:
            source = config.stage + '/' + f'/{dd.year()}{dd.month()}{dd.day()}{dd.hour()}_conv/obs/ioda.oper.ob.PT6H.{obs_type}.{window_start}.nc4'
            if os.path.exists(source):
                print(obs_type)
                # now archive into the shared database
                store(
                    type='obs',
                    provider='ncdiag',
                    date=window_start,
                    obs_type=file_obs_types[obs_type],
                    time_window='PT6H',
                    source_file=source,
                    database='shared'
                )

        directory = f'{config.stage}/{d}_conv'
        logger.info(f'deleting directory {directory}')
        shutil.rmtree(directory)
        print()

