import os
from solo.template import TemplateConstants, Template
from solo.basic_files import clean_path
from solo.logger import Logger
from solo.file_manager import FileManager
from .db_manager import DBManager


class LocalDB:

    logger = Logger(__name__.split('.')[-1])

    def __init__(self, name, config):
        self._root = config['root']
        self._name = name

    def fetch_data(self, source, target, request, archive_side_request):
        if not len(target):
            target = source
        path = clean_path(Template.substitute_string(request['_archive_path'],
                                                     TemplateConstants.DOLLAR_PARENTHESES, archive_side_request.get))
        fetch_dir = Template.substitute_string(os.path.join(self._root, path),
                                               TemplateConstants.DOLLAR_PARENTHESES, archive_side_request.get)
        source_path = os.path.join(fetch_dir, source)
        if '_symlink' in request:
            source_path = source_path.replace(request['_symlink'][0], request['_symlink'][1])

        self.logger.info(f"{self._name}: fetch from {source_path} to {target}")
        FileManager.copy(source_path, target)
        return source_path, target

    def store_data(self, source, target, request, archive_side_request):
        path = clean_path(Template.substitute_string(request['_archive_path'],
                                                     TemplateConstants.DOLLAR_PARENTHESES, archive_side_request.get))
        store_dir = Template.substitute_string(os.path.join(self._root, path),
                                               TemplateConstants.DOLLAR_PARENTHESES, archive_side_request.get)
        if '_symlink' in request:
            store_dir = store_dir.replace(request['_symlink'][0], request['_symlink'][1])
        os.makedirs(store_dir, exist_ok=True)
        store_path = os.path.join(store_dir, target)
        if '_symlink' in request:
            store_path = store_path.replace(request['_symlink'][0], request['_symlink'][1])

        self.logger.info(f"{self._name}: store from {source} to {store_path}")
        FileManager.copy(source, store_path)
        return source, store_path


DBManager.db_factory.register('LocalDB', LocalDB)
