import os
from solo.template import TemplateConstants, Template
from solo.logger import Logger
from solo.file_manager import FileManager
from .db_manager import DBManager


class S3DB:

    logger = Logger(__name__.split('.')[-1])

    def __init__(self, name, config):
        self._bucket = config['bucket']
        self._name = name

    def fetch_data(self, source, target, request, archive_side_request):
        if not len(target):
            target = source
        path = Template.substitute_string(request['_archive_path'],
                                          TemplateConstants.DOLLAR_PARENTHESES, archive_side_request.get)
        source_path = os.path.join(Template.substitute_string(path, TemplateConstants.DOLLAR_PARENTHESES,
                                                              archive_side_request.get),
                                   source)
        if '_symlink' in request:
            source_path = source_path.replace(request['_symlink'][0], request['_symlink'][1])

        # Add a protocol if they don't have one (s3://)
        source_path = FileManager.add_prefix(f'{self._bucket}/{source_path}', 's3')
        self.logger.info(f"{self._name}: fetch from {source_path} to {target}")
        FileManager.copy(source_path, target)
        return source_path, target

    def store_data(self, source, target, request, archive_side_request):
        store_path = os.path.join(
            Template.substitute_string(request['_archive_path'], TemplateConstants.DOLLAR_PARENTHESES,
                                       archive_side_request.get),
            target)
        if '_symlink' in request:
            store_path = store_path.replace(request['_symlink'][0], request['_symlink'][1])

        # Add a protocol if they don't have one (s3://)
        store_path = FileManager.add_prefix(f'{self._bucket}/{store_path}', 's3')
        self.logger.info(f"{self._name}: store from {source} to {store_path}")
        FileManager.copy(source, store_path)
        return source, store_path


DBManager.db_factory.register('S3DB', S3DB)
