import copy
import os
from solo.basic import combine
from solo.logger import Logger
from solo.configuration.configuration import Configuration
from ..database import DBManager
from ..language.directive import Directive


class Base(Directive):

    logger = Logger('r2d2')
    settings = Configuration(os.path.join(os.path.dirname(__file__), '../storage_settings.yaml'))

    def __init__(self, *args, **kwargs):
        # cannot rely on default values here, this is before the language
        # validates the query, but we need this piece of information now.å
        external = kwargs.get('external_schemas', [])
        super().__init__(external, *args, **kwargs)
        print(self)
        print()
        self.logger.info('Starting')
        request = copy.deepcopy(self)
        db = DBManager(self)
        _combine = [x for x in request['_combine'] if x in request]
        combine(_combine, request, self.visitor, db)
        self.logger.info('Success\n')

    def visitor(self, request, database):
        self.action(request, database)

    def action(self, request, database):
        raise NotImplementedError

    @classmethod
    def get_template(cls, request):
        template = request['_templates'][request.type]
        file_format = request.file_format
        if len(file_format):
            if file_format in request['_file_extensions']:
                extension = request['_file_extensions'][file_format]
                template = f'{template}.{extension}'
            else:
                raise IndexError(f'The file format {file_format} is unknown.')
        return template

    @staticmethod
    def archive_side_request(request):
        if '__lowercase' in request:
            request = copy.copy(request)
            for field in request['__lowercase']:
                if field in request:
                    request[field] = request[field].lower()
        return request
