import yaml
from solo.logger import Logger
from solo.language import stringify
from ..database import DBManager
from ..language.directive import Directive


class Report(Directive):

    logger = Logger('report')

    def __init__(self, *args, **kwargs):
        super().__init__([], *args, **kwargs)
        self.generate_report(self.filename, self.detailed, DBManager.journal)
        DBManager.reset_journal()

    @staticmethod
    def generate_report(filename, detailed, journal):
        rows = []
        for action, source, target, request, cached, missing in journal:
            if detailed:
                r = dict(request)
            else:
                r = {}
                for k, i in request.items():
                    if k[0] != '_':
                        r[k] = i
            record = dict(
                source=source,
                target=target,
                missing=missing,
                action=action,
                request=r
            )
            rows.append(record)
        with open(filename, 'w') as f:
            yaml.dump(stringify(rows), f)


report = Report
