# R2D2 Tests

It is not necessarily easy to test an application like R2D2. In the unit tests, we focus on the logical aspects of the applications:
* Make sure the right keywords are taken into account
* Make sure that solo.language resolves the schema definitions of R2D2 correctly
* Make sure fetch and store work correctly together with the cache
* Make sure the file name templating works correctly
* Make sure combining the keywords together works correctly

In order to test those features, we take the following approach:
* We have in the *data* directory a fake R2D2 repository containing yaml files containing fetch request arguments
* We have, next to the yaml files, files with the name of archived files containing the request for that particular file
* We run the fetch command for each yaml file found and we check looking at the fetch report that we have all the files we expected and that the requests for each file is the same as the request generated by the combine as given in the fetch report.
* We define the data directory as an R2D2 database (the source) and decide that when fetching from there, the files are cached
* We define a cache database where all the files fetched are cached
* We define an archive database and every file fetched from the original repository is archived there
* We finally compare the contents of the three databases to make sure the files and their contents are the same

The actual test (test_r2d2.py) is generated using the program: generate_calls.py that takes the template file and creates test_r2d2.py.
The test could be fully dynamic, but although it could test hundreds of scenarios, it would appear as one test. Generating a function by test enables us to keep track of the number of cases tested.

The databases and work files are deleted at the end of the test.

# How to test
The file test_r2d2.py is kept up-to-date in git, however you can always:

```bash
# from r2d2 git repository
cd src/tests
python generate_calls.py  # generates test_r2d2.py
cd .. # now in src
python -m pytest tests
```

Please note that calling pytest directly has a different behaviour, it won't pick up the local r2d2 but the one installed (if there is one). This is why calling python -m pytest is a better approach.
