import os
import shutil
import yaml
from solo.date import Date
from r2d2 import fetch, store

targets = set()


def read_yaml(filename):
    with open(filename) as f:
        return yaml.load(f, Loader=yaml.BaseLoader)


def no_prefix(filename):
    return filename.replace('file://', '')


def run_queries(filename):
    query = read_yaml(filename)
    f = fetch(report='report.yaml', full_report=True, **query)
    targets.add('report.yaml')
    template = f._templates[f['type']]
    extension = f._file_extensions[f.file_format]
    report = read_yaml('report.yaml')
    for fetched_file in report:
        # check that copy works :)
        # filter prefix
        filename = no_prefix(filename)
        source = read_yaml(no_prefix(fetched_file['source']))
        target = read_yaml(no_prefix(fetched_file['target']))
        targets.add(no_prefix(fetched_file['target']))
        assert source == target
        # check that the file contains the same query as in the report
        # this means we copied and names the right file
        request = {}
        for k, i in fetched_file['request'].items():
            if k in target:
                request[k] = i
        request['date'] = Date(request['date'])
        target['date'] = Date(target['date'])
        assert request == target
     # store the files we just retrieved
    store(source_file=f'{template}.{extension}', database='archive', **query)


def file_list(path):
    l = []
    f = []
    for dir_path, dir_names, filenames in os.walk(path):
        for filename in filenames:
            parts = filename.split('.')
            if parts[-1] != 'yaml':
                l.append(os.path.join(dir_path, filename))
                f.append(os.path.basename(filename))
    return l, f


def compare_dirs(a, b):
    a_list, a_files = file_list(a)
    b_list, b_files = file_list(b)
    assert a_files == b_files
    for a, b in zip(a_list, b_list):
        ra = read_yaml(a)
        rb = read_yaml(b)
        assert ra == rb


def setup():
    os.environ['R2D2_CONFIG'] = 'tests/config.yaml'


def cleanup():
    config = read_yaml('tests/config.yaml')
    for target in targets:
        os.unlink(target)
    shutil.rmtree(config['databases']['archive']['root'])
    shutil.rmtree(config['databases']['cache']['root'])